@@ -4,7 +4,7 @@ mkdir('m', 0777);
 
 my @c = (
     (map {chr($_)}                 (0x20..0x7E, 0xA1..0xDF)),
-    qw( \n \r \t \f \b \a \e ),
+    qw( \n \r \t \f \a \e ),
     (map {sprintf('\\%03o',$_)}    (0x20..0x7E, 0xA1..0xDF)),
     (map {sprintf('\\x%02x',$_)}   (0x20..0x7E, 0xA1..0xDF)),
     (map {sprintf('\\c%c',$_)}     (0x40..0x5B, 0x5D..0x5F)),
@@ -12,7 +12,8 @@ my @c = (
 );
 
 my $script = "m\\m.pl";
-open(SCRIPT,">$script") || die "Can't open file: $script\n";
+open(SCRIPT,">$script")      || die "Can't open file: $script\n";
+open(WANT,  ">$script.want") || die "Can't open file: $script.want\n";
 
 #----------------------------------------------------------------------------
 # / /
@@ -32,11 +33,14 @@ for my $c (@c) {
     else {
         print SCRIPT "print /",   $c, "/, \"\\n\";\n";
     }
+
+    print WANT '1', "\n";
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\$_ = \"", chr($c1), chr($c2), "\"; print /", chr($c1), chr($c2), "/, \"\\n\";\n";
+        print WANT '1', "\n";
     }
 }
 
@@ -63,15 +67,20 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 #      else {
 #          print SCRIPT "print ?",   $c, "?, \"\\n\";\n";
 #      }
+#  
+#      print WANT '1', "\n";
 #  }
 #  
 #  for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 #      for my $c2 (0x40..0x7E, 0x80..0xFC) {
 #          print SCRIPT "\$_ = \"", chr($c1), chr($c2), "\"; print ?", chr($c1), chr($c2), "?, \"\\n\";\n";
+#          print WANT '1', "\n";
 #      }
 #  }
 #  
+
 close(SCRIPT);
+close(WANT);
 
 #----------------------------------------------------------------------------
 # m * *
@@ -86,7 +95,8 @@ for my $delim (0x20..0x7E, 0xA1..0xDF) {
     }
 
     my $script = sprintf("m\\m-%02X.pl", $delim);
-    open(SCRIPT,">$script") || die "Can't open file: $script\n";
+    open(SCRIPT,">$script")      || die "Can't open file: $script\n";
+    open(WANT,  ">$script.want") || die "Can't open file: $script.want\n";
 
     my $end_delimiter = {
                         '(' => ')',
@@ -123,15 +133,19 @@ for my $delim (0x20..0x7E, 0xA1..0xDF) {
         else {
             print SCRIPT "print m", $delimiter,       $c, $end_delimiter, ", \"\\n\";\n";
         }
+
+        print WANT '1', "\n";
     }
 
     for my $c1 (0x81..0x9F, 0xE0..0xFC) {
         for my $c2 (0x40..0x7E, 0x80..0xFC) {
             print SCRIPT "\$_ = \"", chr($c1), chr($c2), "\"; print m", $delimiter, chr($c1), chr($c2), $end_delimiter, ", \"\\n\";\n";
+            print WANT '1', "\n";
         }
     }
 
     close(SCRIPT);
+    close(WANT);
 }
 
 #----------------------------------------------------------------------------
