@@ -4,7 +4,7 @@ mkdir('qr', 0777);
 
 my @c = (
     (map {chr($_)}                 (0x20..0x7E, 0xA1..0xDF)),
-    qw( \n \r \t \f \b \a \e ),
+    qw( \n \r \t \f \a \e ),
     (map {sprintf('\\%03o',$_)}    (0x20..0x7E, 0xA1..0xDF)),
     (map {sprintf('\\x%02x',$_)}   (0x20..0x7E, 0xA1..0xDF)),
     (map {sprintf('\\c%c',$_)}     (0x40..0x5B, 0x5D..0x5F)),
@@ -23,7 +23,8 @@ for my $delim (0x20..0x7E, 0xA1..0xDF) {
     }
 
     my $script = sprintf("qr\\qr-%02X.pl", $delim);
-    open(SCRIPT,">$script") || die "Can't open file: $script\n";
+    open(SCRIPT,">$script")      || die "Can't open file: $script\n";
+    open(WANT,  ">$script.want") || die "Can't open file: $script.want\n";
 
     my $end_delimiter = {
                         '(' => ')',
@@ -55,20 +56,29 @@ for my $delim (0x20..0x7E, 0xA1..0xDF) {
         }
 
         if ($c =~ /^([\\\$\@]|[\\\|\(\)\[\{\^\$\*\+\?\.]|\Q$delimiter\E|\Q$end_delimiter\E)$/) {
-            print SCRIPT 'print qr', $delimiter, '\\', $c, $end_delimiter, ", \"\\n\";\n";
+            print SCRIPT '$qr = qr', $delimiter, '\\', $c, $end_delimiter, '; ';
         }
         else {
-            print SCRIPT 'print qr', $delimiter,       $c, $end_delimiter, ", \"\\n\";\n";
+            print SCRIPT '$qr = qr', $delimiter,       $c, $end_delimiter, '; ';
         }
+
+        print SCRIPT 'print $_ =~ $qr, "\n";', "\n";
+
+        print WANT '1', "\n";
     }
 
     for my $c1 (0x81..0x9F, 0xE0..0xFC) {
         for my $c2 (0x40..0x7E, 0x80..0xFC) {
-            print SCRIPT "\$_ = \"", chr($c1), chr($c2), "\"; print qr", $delimiter, chr($c1), chr($c2), $end_delimiter, ", \"\\n\";\n";
+            print SCRIPT '$_ = "', chr($c1), chr($c2), '"; ';
+            print SCRIPT '$qr = qr', $delimiter, chr($c1), chr($c2), $end_delimiter, '; ';
+            print SCRIPT 'print $_ =~ $qr, "\n";', "\n";
+
+            print WANT '1', "\n";
         }
     }
 
     close(SCRIPT);
+    close(WANT);
 }
 
 #----------------------------------------------------------------------------
