@@ -4,7 +4,7 @@ mkdir('s', 0777);
 
 my @c = (
     (map {chr($_)}                 (0x20..0x7E, 0xA1..0xDF)),
-    qw( \n \r \t \f \b \a \e ),
+    qw( \n \r \t \f \a \e ),
     (map {sprintf('\\%03o',$_)}    (0x20..0x7E, 0xA1..0xDF)),
     (map {sprintf('\\x%02x',$_)}   (0x20..0x7E, 0xA1..0xDF)),
     (map {sprintf('\\c%c',$_)}     (0x40..0x5B, 0x5D..0x5F)),
@@ -40,7 +40,8 @@ for my $delim (0x20..0x7E, 0xA1..0xDF) {
             }
 
             my $script = sprintf("s\\s-%02X%02X.pl", $delim, $delim2);
-            open(SCRIPT,">$script") || die "Can't open file: $script\n";
+            open(SCRIPT,">$script")      || die "Can't open file: $script\n";
+            open(WANT,  ">$script.want") || die "Can't open file: $script.want\n";
 
             my $end_delimiter2 = {
                         '(' => ')',
@@ -117,6 +118,8 @@ for my $delim (0x20..0x7E, 0xA1..0xDF) {
                     }
                     print SCRIPT ", \"\\n\";\n";
                 }
+
+                print WANT '1', "\n";
             }
 
             for my $c1 (0x81..0x9F, 0xE0..0xFC) {
@@ -125,10 +128,12 @@ for my $delim (0x20..0x7E, 0xA1..0xDF) {
                     print SCRIPT $delimiter,  chr($c1), chr($c2), $end_delimiter;
                     print SCRIPT $delimiter2, chr($c1), chr($c2), $end_delimiter2;
                     print SCRIPT ", \"\\n\";\n";
+                    print WANT '1', "\n";
                 }
             }
 
             close(SCRIPT);
+            close(WANT);
         }
     }
 
@@ -138,7 +143,8 @@ for my $delim (0x20..0x7E, 0xA1..0xDF) {
 
     else {
         my $script = sprintf("s\\s-%02X.pl", $delim);
-        open(SCRIPT,">$script") || die "Can't open file: $script\n";
+        open(SCRIPT,">$script")      || die "Can't open file: $script\n";
+        open(WANT,  ">$script.want") || die "Can't open file: $script.want\n";
 
         for my $c (@c) {
 
@@ -168,15 +174,19 @@ for my $delim (0x20..0x7E, 0xA1..0xDF) {
             else {
                 print SCRIPT "print s", $delimiter,       $c, $delimiter,       $c, $delimiter, ", \"\\n\";\n";
             }
+
+            print WANT '1', "\n";
         }
 
         for my $c1 (0x81..0x9F, 0xE0..0xFC) {
             for my $c2 (0x40..0x7E, 0x80..0xFC) {
                 print SCRIPT "\$_ = \"", chr($c1), chr($c2), "\"; print s", $delimiter, chr($c1), chr($c2), $delimiter, chr($c1), chr($c2), $delimiter, ", \"\\n\";\n";
+                print WANT '1', "\n";
             }
         }
 
         close(SCRIPT);
+        close(WANT);
     }
 }
 
