@@ -40,7 +40,8 @@ for my $delim (0x20..0x7E, 0xA1..0xDF) {
             }
 
             my $script = sprintf("tr\\tr-%02X%02X.pl", $delim, $delim2);
-            open(SCRIPT,">$script") || die "Can't open file: $script\n";
+            open(SCRIPT,">$script")      || die "Can't open file: $script\n";
+            open(WANT,  ">$script.want") || die "Can't open file: $script.want\n";
 
             my $end_delimiter2 = {
                         '(' => ')',
@@ -80,6 +81,8 @@ for my $delim (0x20..0x7E, 0xA1..0xDF) {
                     }
                     print SCRIPT ", \"\\n\";\n";
                 }
+
+                print WANT '1', "\n";
             }
 
             for my $c1 (0x81..0x9F, 0xE0..0xFC) {
@@ -88,10 +91,12 @@ for my $delim (0x20..0x7E, 0xA1..0xDF) {
                     print SCRIPT $delimiter,  chr($c1), chr($c2), $end_delimiter;
                     print SCRIPT $delimiter2, chr($c1), chr($c2), $end_delimiter2;
                     print SCRIPT ", \"\\n\";\n";
+                    print WANT '1', "\n";
                 }
             }
 
             close(SCRIPT);
+            close(WANT);
         }
     }
 
@@ -101,7 +106,8 @@ for my $delim (0x20..0x7E, 0xA1..0xDF) {
 
     else {
         my $script = sprintf("tr\\tr-%02X.pl", $delim);
-        open(SCRIPT,">$script") || die "Can't open file: $script\n";
+        open(SCRIPT,">$script")      || die "Can't open file: $script\n";
+        open(WANT,  ">$script.want") || die "Can't open file: $script.want\n";
 
         for my $c (@c) {
 
@@ -122,15 +128,19 @@ for my $delim (0x20..0x7E, 0xA1..0xDF) {
             else {
                 print SCRIPT 'print tr', $delimiter, $c, $delimiter, $c, $delimiter, ", \"\\n\";\n";
             }
+
+            print WANT '1', "\n";
         }
 
         for my $c1 (0x81..0x9F, 0xE0..0xFC) {
             for my $c2 (0x40..0x7E, 0x80..0xFC) {
                 print SCRIPT "\$_ = \"", chr($c1), chr($c2), "\"; print tr", $delimiter, chr($c1), chr($c2), $delimiter, chr($c1), chr($c2), $delimiter, ", \"\\n\";\n";
+                print WANT '1', "\n";
             }
         }
 
         close(SCRIPT);
+        close(WANT);
     }
 }
 
