@@ -7,24 +7,32 @@ my @c = (
 );
 
 my $script = "uc\\uc.pl";
-open(SCRIPT,">$script") || die "Can't open file: $script\n";
+open(SCRIPT,">$script")      || die "Can't open file: $script\n";
+open(WANT,  ">$script.want") || die "Can't open file: $script.want\n";
 
 #----------------------------------------------------------------------------
 # uc
 #----------------------------------------------------------------------------
 
 for my $c (@c) {
-    if ($c =~ /^['\\]$/) {
+    if ($c =~ /^[abcdefghijklmnopqrstuvwxyz]$/) {
+        print SCRIPT "\$_ = '", $c, "'; print uc, \"\\n\";\n";
+        print WANT uc($c), "\n";
+    }
+    elsif ($c =~ /^['\\]$/) {
         print SCRIPT "\$_ = '\\", $c, "'; print uc, \"\\n\";\n";
+        print WANT $c, "\n";
     }
     else {
         print SCRIPT "\$_ = '", $c, "'; print uc, \"\\n\";\n";
+        print WANT $c, "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\$_ = '", chr($c1), chr($c2), "'; print uc, \"\\n\";\n";
+        print WANT chr($c1), chr($c2), "\n";
     }
 }
 
@@ -33,17 +41,24 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 #----------------------------------------------------------------------------
 
 for my $c (@c) {
-    if ($c =~ /^['\\]$/) {
+    if ($c =~ /^[abcdefghijklmnopqrstuvwxyz]$/) {
+        print SCRIPT "\$_ = '", $c, "'; print uc \$_, \"\\n\";\n";
+        print WANT uc($c), "\n";
+    }
+    elsif ($c =~ /^['\\]$/) {
         print SCRIPT "\$_ = '\\", $c, "'; print uc \$_, \"\\n\";\n";
+        print WANT $c, "\n";
     }
     else {
         print SCRIPT "\$_ = '", $c, "'; print uc \$_, \"\\n\";\n";
+        print WANT $c, "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\$_ = '", chr($c1), chr($c2), "'; print uc \$_, \"\\n\";\n";
+        print WANT chr($c1), chr($c2), "\n";
     }
 }
 
@@ -52,17 +67,24 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 #----------------------------------------------------------------------------
 
 for my $c (@c) {
-    if ($c =~ /^['\\]$/) {
+    if ($c =~ /^[abcdefghijklmnopqrstuvwxyz]$/) {
+        print SCRIPT "\$_ = '", $c, "'; print uc(\$_), \"\\n\";\n";
+        print WANT uc($c), "\n";
+    }
+    elsif ($c =~ /^['\\]$/) {
         print SCRIPT "\$_ = '\\", $c, "'; print uc(\$_), \"\\n\";\n";
+        print WANT $c, "\n";
     }
     else {
         print SCRIPT "\$_ = '", $c, "'; print uc(\$_), \"\\n\";\n";
+        print WANT $c, "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\$_ = '", chr($c1), chr($c2), "'; print uc(\$_), \"\\n\";\n";
+        print WANT chr($c1), chr($c2), "\n";
     }
 }
 
@@ -71,17 +93,24 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 #----------------------------------------------------------------------------
 
 for my $c (@c) {
-    if ($c =~ /^['\\]$/) {
+    if ($c =~ /^[abcdefghijklmnopqrstuvwxyz]$/) {
+        print SCRIPT "\$_ = '", $c, "'; print uc \$_, 'a', 'b', 'c'; print \"\\n\";\n";
+        print WANT uc($c), 'a', 'b', 'c', "\n";
+    }
+    elsif ($c =~ /^['\\]$/) {
         print SCRIPT "\$_ = '\\", $c, "'; print uc \$_, 'a', 'b', 'c'; print \"\\n\";\n";
+        print WANT $c, 'a', 'b', 'c', "\n";
     }
     else {
         print SCRIPT "\$_ = '", $c, "'; print uc \$_, 'a', 'b', 'c'; print \"\\n\";\n";
+        print WANT $c, 'a', 'b', 'c', "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\$_ = '", chr($c1), chr($c2), "'; print uc \$_, 'a', 'b', 'c'; print \"\\n\";\n";
+        print WANT chr($c1), chr($c2), 'a', 'b', 'c', "\n";
     }
 }
 
@@ -90,17 +119,24 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 #----------------------------------------------------------------------------
 
 for my $c (@c) {
-    if ($c =~ /^['\\]$/) {
+    if ($c =~ /^[abcdefghijklmnopqrstuvwxyz]$/) {
+        print SCRIPT "print uc '", $c, "', \"\\n\";\n";
+        print WANT uc($c), "\n";
+    }
+    elsif ($c =~ /^['\\]$/) {
         print SCRIPT "print uc '\\", $c, "', \"\\n\";\n";
+        print WANT $c, "\n";
     }
     else {
         print SCRIPT "print uc '", $c, "', \"\\n\";\n";
+        print WANT $c, "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "print uc '", chr($c1), chr($c2), "', \"\\n\";\n";
+        print WANT chr($c1), chr($c2), "\n";
     }
 }
 
@@ -109,17 +145,24 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 #----------------------------------------------------------------------------
 
 for my $c (@c) {
-    if ($c =~ /^['\\]$/) {
+    if ($c =~ /^[abcdefghijklmnopqrstuvwxyz]$/) {
+        print SCRIPT "print uc('", $c, "'), \"\\n\";\n";
+        print WANT uc($c), "\n";
+    }
+    elsif ($c =~ /^['\\]$/) {
         print SCRIPT "print uc('\\", $c, "'), \"\\n\";\n";
+        print WANT $c, "\n";
     }
     else {
         print SCRIPT "print uc('", $c, "'), \"\\n\";\n";
+        print WANT $c, "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "print uc('", chr($c1), chr($c2), "'), \"\\n\";\n";
+        print WANT chr($c1), chr($c2), "\n";
     }
 }
 
@@ -128,20 +171,28 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 #----------------------------------------------------------------------------
 
 for my $c (@c) {
-    if ($c =~ /^['\\]$/) {
+    if ($c =~ /^[abcdefghijklmnopqrstuvwxyz]$/) {
+        print SCRIPT "print uc '", $c, "', 'a', 'b', 'c'; print \"\\n\";\n";
+        print WANT uc($c), 'a', 'b', 'c', "\n";
+    }
+    elsif ($c =~ /^['\\]$/) {
         print SCRIPT "print uc '\\", $c, "', 'a', 'b', 'c'; print \"\\n\";\n";
+        print WANT $c, 'a', 'b', 'c', "\n";
     }
     else {
         print SCRIPT "print uc '", $c, "', 'a', 'b', 'c'; print \"\\n\";\n";
+        print WANT $c, 'a', 'b', 'c', "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "print uc '", chr($c1), chr($c2), "', 'a', 'b', 'c'; print \"\\n\";\n";
+        print WANT chr($c1), chr($c2), 'a', 'b', 'c', "\n";
     }
 }
 
 close(SCRIPT);
+close(WANT);
 
 #----------------------------------------------------------------------------
